Learn R Programming

SMFilter (version 1.0.3)

rvlb_sm: Sample from the vector Langevin-Bingham on the Stiefel manifold.

Description

This function draws a sample from the vector Langevin-Bingham on the Stiefel manifold.

Usage

rvlb_sm(num, mA, vc, vx)

Arguments

num

number of observations or sample size.

mA

the matrix A which is symmetric ip*ip matrix.

vc

the vector c with dimension ip.

vx

the vector x, the initial value.

Value

an array containing a sample of draws from the vector Langevin-Bingham on the Stiefel manifold.

Details

The vector Langevin-Bingham distribution on the Stiefel manifold has the density kernel: $$f(X) \propto \mathrm{etr}\{ x' A x + c' x \}$$ where \(x\) satisfies \(x'x = 1\), and \(A\) is a symmetric matrix.

References

Hoff, P. D. (2009) "Simulation of the Matrix Bingham<U+2014>von Mises<U+2014>Fisher Distribution, With Applications to Multivariate and Relational Data", Journal of Computational and Graphical Statistics, Vol. 18, pp. 438-456.