This function draws a sample from the vector Langevin-Bingham on the Stiefel manifold.
rvlb_sm(num, mA, vc, vx)number of observations or sample size.
the matrix A which is symmetric ip*ip matrix.
the vector c with dimension ip.
the vector x, the initial value.
an array containing a sample of draws from the vector Langevin-Bingham on the Stiefel manifold.
The vector Langevin-Bingham distribution on the Stiefel manifold has the density kernel: $$f(X) \propto \mathrm{etr}\{ x' A x + c' x \}$$ where \(x\) satisfies \(x'x = 1\), and \(A\) is a symmetric matrix.
Hoff, P. D. (2009) "Simulation of the Matrix Bingham<U+2014>von Mises<U+2014>Fisher Distribution, With Applications to Multivariate and Relational Data", Journal of Computational and Graphical Statistics, Vol. 18, pp. 438-456.